@@ -256,6 +256,8 @@ class P(object):
     def within(*args):
         if len(args) == 1 and type(args[0]) == list:
             return P("within", args[0])
+        elif len(args) == 1 and type(args[0]) == set:
+            return P("within", list(args[0]))
         else:
             return P("within", list(args))
         
@@ -263,6 +265,8 @@ class P(object):
     def without(*args):
         if len(args) == 1 and type(args[0]) == list:
             return P("without", args[0])
+        elif len(args) == 1 and type(args[0]) == set:
+            return P("without", list(args[0]))
         else:
             return P("without", list(args))
 
@@ -534,7 +538,7 @@ class TraversalStrategies(object):
     global_cache = {}
 
     def __init__(self, traversal_strategies=None):
-        self.traversal_strategies =             traversal_strategies.traversal_strategies if traversal_strategies is not None else []
+        self.traversal_strategies = traversal_strategies.traversal_strategies if traversal_strategies is not None else []
 
     def add_strategies(self, traversal_strategies):
         self.traversal_strategies = self.traversal_strategies + traversal_strategies
@@ -650,6 +654,22 @@ class Bytecode(object):
         return (str(self.source_instructions) if len(self.source_instructions) > 0 else "") + \
                (str(self.step_instructions) if len(self.step_instructions) > 0 else "")
 
+    @staticmethod
+    def _create_graph_op(name, *values):
+        bc = Bytecode()
+        bc.add_source(name, *values)
+        return bc
+
+    @staticmethod
+    class GraphOp:
+        @staticmethod
+        def commit():
+            return Bytecode._create_graph_op("tx", "commit")
+
+        @staticmethod
+        def rollback():
+            return Bytecode._create_graph_op("tx", "rollback")
+
 
 '''
 BINDINGS
