@@ -32,7 +32,7 @@ from isodate import parse_duration, duration_isoformat
 
 from gremlin_python import statics
 from gremlin_python.statics import FloatType, FunctionType, IntType, LongType, TypeType, SingleByte, ByteBufferType, SingleChar
-from gremlin_python.process.traversal import Binding, Bytecode, P, Traversal, Traverser, TraversalStrategy
+from gremlin_python.process.traversal import Binding, Bytecode, P, TextP, Traversal, Traverser, TraversalStrategy
 from gremlin_python.structure.graph import Edge, Property, Vertex, VertexProperty, Path
 
 # When we fall back to a superclass's serializer, we iterate over this map.
@@ -140,9 +140,9 @@ class _GraphSONTypeIO(object):
 
     symbolMap = {"global_": "global", "as_": "as", "in_": "in", "and_": "and",
                  "or_": "or", "is_": "is", "not_": "not", "from_": "from",
-                 "set_": "set", "list_": "list", "all_": "all",
+                 "set_": "set", "list_": "list", "all_": "all", "with_": "with",
                  "filter_": "filter", "id_": "id", "max_": "max", "min_": "min", "sum_": "sum"}
-    
+
     @classmethod
     def unmangleKeyword(cls, symbol):
         return cls.symbolMap.get(symbol, symbol)
@@ -284,6 +284,17 @@ class PSerializer(_GraphSONTypeIO):
         return GraphSONUtil.typedValue("P", out)
 
 
+class TextPSerializer(_GraphSONTypeIO):
+    python_type = TextP
+
+    @classmethod
+    def dictify(cls, p, writer):
+        out = {"predicate": p.operator,
+               "value": [writer.toDict(p.value), writer.toDict(p.other)] if p.other is not None else
+               writer.toDict(p.value)}
+        return GraphSONUtil.typedValue("TextP", out)
+
+
 class BindingSerializer(_GraphSONTypeIO):
     python_type = Binding
 
@@ -304,12 +315,7 @@ class LambdaSerializer(_GraphSONTypeIO):
         language = statics.default_lambda_language if isinstance(lambda_result, str) else lambda_result[1]
         out = {"script": script,
                "language": language}
-        if language == "gremlin-jython" or language == "gremlin-python":
-            if not script.strip().startswith("lambda"):
-                script = "lambda " + script
-                out["script"] = script
-            out["arguments"] = six.get_function_code(eval(out["script"])).co_argcount
-        elif language == "gremlin-groovy" and "->" in script:
+        if language == "gremlin-groovy" and "->" in script:
             # if the user has explicitly added parameters to the groovy closure then we can easily detect one or two
             # arg lambdas - if we can't detect 1 or 2 then we just go with "unknown"
             args = script[0:script.find("->")]
@@ -471,7 +477,7 @@ class Int64IO(_NumberIO):
 
     @classmethod
     def dictify(cls, n, writer):
-        # if we exceed Java long range then we need a BigInteger 
+        # if we exceed Java long range then we need a BigInteger
         if isinstance(n, bool):
             return n
         elif n < -9223372036854775808 or n > 9223372036854775807:
@@ -489,6 +495,18 @@ class Int32IO(Int64IO):
     graphson_type = "g:Int32"
     graphson_base_type = "Int32"
 
+    @classmethod
+    def dictify(cls, n, writer):
+        # if we exceed Java int range then we need a long
+        if isinstance(n, bool):
+            return n
+        elif n < -9223372036854775808 or n > 9223372036854775807:
+            return GraphSONUtil.typedValue("BigInteger", str(n), "gx")
+        elif n < -2147483648 or n > 2147483647:
+            return GraphSONUtil.typedValue("Int64", n)
+        else:
+            return GraphSONUtil.typedValue(cls.graphson_base_type, n)
+
 
 class ByteIO(_NumberIO):
     python_type = SingleByte
